@@ -1,11 +1,14 @@
 import FIXTURES from '../../../testing/fixtures'
 import Analyzer from '../analyser'
+import { initializeParser } from '../parser'
 
-const analyzer = new Analyzer()
+let analyzer: Analyzer
 
 const CURRENT_URI = 'dummy-uri.sh'
-beforeEach(() => {
-  analyzer.analyze(CURRENT_URI, FIXTURES.INSTALL)
+
+beforeAll(async () => {
+  const parser = await initializeParser()
+  analyzer = new Analyzer(parser)
 })
 
 describe('analyze', () => {
@@ -29,11 +32,13 @@ describe('analyze', () => {
 
 describe('findDefinition', () => {
   it('returns empty list if parameter is not found', () => {
+    analyzer.analyze(CURRENT_URI, FIXTURES.INSTALL)
     const result = analyzer.findDefinition('foobar')
     expect(result).toEqual([])
   })
 
   it('returns a list of locations if parameter is found', () => {
+    analyzer.analyze(CURRENT_URI, FIXTURES.INSTALL)
     const result = analyzer.findDefinition('node_version')
     expect(result).not.toEqual([])
     expect(result).toMatchSnapshot()
@@ -42,11 +47,13 @@ describe('findDefinition', () => {
 
 describe('findReferences', () => {
   it('returns empty list if parameter is not found', () => {
+    analyzer.analyze(CURRENT_URI, FIXTURES.INSTALL)
     const result = analyzer.findReferences('foobar')
     expect(result).toEqual([])
   })
 
   it('returns a list of locations if parameter is found', () => {
+    analyzer.analyze(CURRENT_URI, FIXTURES.INSTALL)
     const result = analyzer.findReferences('node_version')
     expect(result).not.toEqual([])
     expect(result).toMatchSnapshot()
@@ -55,11 +62,13 @@ describe('findReferences', () => {
 
 describe('findSymbols', () => {
   it('returns empty list if uri is not found', () => {
+    analyzer.analyze(CURRENT_URI, FIXTURES.INSTALL)
     const result = analyzer.findSymbols('foobar.sh')
     expect(result).toEqual([])
   })
 
   it('returns a list of SymbolInformation if uri is found', () => {
+    analyzer.analyze(CURRENT_URI, FIXTURES.INSTALL)
     const result = analyzer.findSymbols(CURRENT_URI)
     expect(result).not.toEqual([])
     expect(result).toMatchSnapshot()
@@ -75,6 +84,7 @@ describe('findSymbols', () => {
 
 describe('wordAtPoint', () => {
   it('returns current word at a given point', () => {
+    analyzer.analyze(CURRENT_URI, FIXTURES.INSTALL)
     expect(analyzer.wordAtPoint(CURRENT_URI, 25, 5)).toEqual('rm')
     // FIXME: seems like there is an issue here:
     // expect(analyzer.wordAtPoint(CURRENT_URI, 24, 4)).toEqual('else')
@@ -83,6 +93,7 @@ describe('wordAtPoint', () => {
 
 describe('findSymbolCompletions', () => {
   it('return a list of symbols', () => {
+    analyzer.analyze(CURRENT_URI, FIXTURES.INSTALL)
     expect(analyzer.findSymbolCompletions(CURRENT_URI)).toMatchSnapshot()
   })
 })
